'''
  Folding@Home Client Control (FAHControl)
  Copyright (C) 2010-2011 Stanford University

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

import gtk
import gobject
import copy

from fah.util import parse_bool
from fah.util import status_to_color


class SlotConfig:
    def __init__(
        self, id = -1, status = None, description = None, options = {}):

        self.id = int(id)
        self.status = status
        self.description = description
        self.options = options

        if status is not None: self.status = status.title()
        if description is None: self.description = 'uniprocessor'

        # Type
        if self.description.startswith('uni'): self.type = 'uniprocessor'
        elif self.description.startswith('smp'): self.type = 'smp'
        elif self.description.startswith('gpu'): self.type = 'gpu'
        else: raise Exception, 'Invalid slot type "%s"' % description


    def add_to_ui(self, app):
        wrapper = gobject.GObject()
        wrapper.slot = copy.deepcopy(self)
        app.slot_list.append((self.id, self.type, wrapper))


    @staticmethod
    def clear_dialog(app):
        app.slot_option_list.clear()
        app.slot_type_uni.set_active(True)
        app.slot_option_widgets['gpu_id'].set_value(-1)
        app.slot_option_widgets['cpus'].set_value(0)


    def save_dialog(self, app):
        self.options = {}

        if app.slot_type_uni.get_active(): self.type = 'uniprocessor'

        elif app.slot_type_smp.get_active():
            self.type = 'smp'

            cpus = str(int(app.slot_option_widgets['cpus'].get_value()))
            if int(cpus): self.options['cpus'] = cpus

        elif app.slot_type_gpu.get_active():
            self.type = 'gpu'

            gpu_id = int(app.slot_option_widgets['gpu_id'].get_value())
            if gpu_id == -1:
                if 'gpu-id' in self.options: del self.options['gpu-id']
            else: self.options['gpu-id'] = str(gpu_id)

        # Extra options
        def add_option(model, path, iter, data = None):
            name = model.get(iter, 0)[0]
            value = model.get(iter, 1)[0]
            self.options[name] = value

        app.slot_option_list.foreach(add_option)


    def load_dialog(self, app):
        # Type
        if self.type == 'uniprocessor': app.slot_type_uni.set_active(True)
        elif self.type == 'smp': app.slot_type_smp.set_active(True)
        elif self.type == 'gpu': app.slot_type_gpu.set_active(True)
        else: raise Exception, 'Invalid slot type "%s"' % self.type

        # SMP
        if 'cpus' in self.options: cpus = float(self.options['cpus'])
        else: cpus = 0
        app.slot_option_widgets['cpus'].set_value(cpus)

        # GPU
        if 'gpu-id' in self.options: gpu_id = float(self.options['gpu-id'])
        else: gpu_id = -1
        app.slot_option_widgets['gpu_id'].set_value(gpu_id)

        # Options
        used = set(['cpus', 'gpu-id', 'gpu', 'smp'])
        app.slot_option_list.clear()
        for name, value in self.options.items():
            if not name in used:
                app.slot_option_list.append((name, value))
