import sys
import os
import inspect

dir = os.path.dirname(inspect.getfile(inspect.currentframe()))
if dir == '': dir = '.'
print 'dir =', dir

os.chdir(dir)

# Convert glade data
in_file = 'fah/FAHControl.glade'
out_file = 'fah/FAHControl_glade.py'
input = None
output = None
try:
    input = open(in_file, 'r')
    output = open(out_file, 'w')

    output.write('# -*- coding: utf8 -*-\n\n')
    output.write('glade_data = """')
    output.write(input.read())
    output.write('"""\n')
finally:
    if input is not None: input.close()
    if output is not None: output.close()


# Bootstrap
try:
    import ez_setup
    ez_setup.use_setuptools()
except: pass

app = 'FAHControl'

if sys.platform == 'darwin':
    from setuptools import setup

    files = []

    plist = dict(
        CFBundleDisplayName = 'Folding@home Client',
        CFBundleIdentifier = 'edu.stanford.folding',
        CFBundleSignature = 'fahc',
        NSHumanReadableCopyright = 'Copyright 2010-2011, Stanford University',
        )

    options = dict(
            argv_emulation = True,
            includes = 'cairo, pango, pangocairo, atk, gobject, gio',
            iconfile = 'FAHLogo.icns',
            plist = plist,
            )

    extra_opts = dict(
        app = [app],
        data_files = files,
        options = {'py2app': options},
        setup_requires = ['py2app'],
    )

    # Hack around py2app problem with python scripts with out .py extension.
    from py2app.util import PY_SUFFIXES
    PY_SUFFIXES.append('')

elif sys.platform == 'win32':
    from cx_Freeze import setup, Executable

    e = Executable(
        app,
        base = 'Win32GUI',
        icon = 'FAHClient.ico')
    options = {'build_exe': {'build_exe': 'gui'}}

    extra_opts = dict(
        executables = [e],
        options = options)

else:
    from setuptools import setup, find_packages

    extra_opts = dict(
        packages = find_packages(),
        scripts = [app],
        install_requires = 'gtk2 >= 2.14.0',
        )

try:
    version = open('version.txt').read().strip()
except: version = None

if version is not None:
    open('fah/Version.py', 'w').write('version = \'%s\'\n' % version)

setup(
    name = 'FAHControl',
    version = version,
    description = 'Folding@home Client Control',
    author = 'Joseph Coffland',
    author_email = 'joseph@cauldrondevelopment.com',
    license = 'GNU General Public License version 3',
    keywords = 'protein, molecular dynamics, simulation',
    url = 'http://folding.stanford.edu/',
    package_data = {'fah': ['*.glade']},
    **extra_opts)
